@@ -103,7 +103,7 @@ def velocity_limits_update(low_bounds,up_bounds,n_vars,n_particles,iteration,n_i
         The maximum and minimum velocity
     """
 
-    f=0.5-((0.3-0.1)/n_iterations)*iteration
+    f=0.5-((0.5-0.01)/n_iterations)*iteration
     VelMax=np.array([[f*(up_bounds[j,i]-low_bounds[j,i]) for i in range(n_vars)] for j in range(n_particles)])
     VelMin=-VelMax
     return VelMax,VelMin
@@ -130,7 +130,7 @@ def BRM_control_bounce_back(new_position,low_bounds,up_bounds):
 
     # Bounce Back update
     position=np.minimum(new_position, up_bounds)
-    position=np.maximum(new_position, low_bounds)    
+    position=np.maximum(position, low_bounds)    
     return position, 0
 
 
@@ -220,7 +220,7 @@ def BRM_control_adaptive_penalty(new_position,low_bounds,up_bounds):
         elif new_position[i]<low_bounds[i]:
             penalty+= (low_bounds[i] - new_position[i])
             quantity+=1
-    return new_position, (penalty*quantity*100)
+    return new_position, (penalty*quantity*10000)
 
 
 def PSO_alg(wmax,wmin,c1min,c1max,c2min,c2max,initial_solution,brm_function,perc_repair,
@@ -245,7 +245,7 @@ def PSO_alg(wmax,wmin,c1min,c1max,c2min,c2max,initial_solution,brm_function,perc
         initial_solution: matrix or array
             Matrix or array containing the initial solutions or solution
         brm_function: function
-            Function to handle boundary constraint violation. One of: BRM_control_bounce_back, BRM_control_random_reinitialization, BRM_control_brick_wall_penalty, BRM_control_adaptive_penalty or a custom one created by the user. 
+            Function to handle boundary constraint violation. One of: BRM_control_brick_wall_penalty (1), BRM_control_adaptive_penalty (2), BRM_control_random_reinitialization (3), BRM_control_bounce_back (4), or a custom one created by the user. 
         perc_repair: float
             Value between 0 and 1 that determines the percentage of iterations starting from the end where a repair function is applied
         n_iterations: int
@@ -313,7 +313,7 @@ def PSO_alg(wmax,wmin,c1min,c1max,c2min,c2max,initial_solution,brm_function,perc
         #Update position
         for i in range(n_particles):
             # new volocity calculation
-            new_velocity = (W*velocity_vector[i]) + (c1*random.random()) * (pbest_position[i] - particle_position_vector[i]) + (c2*random.random()) * (gbest_position-particle_position_vector[i])
+            new_velocity = (W*velocity_vector[i]) + (c1*np.random.uniform()) * (pbest_position[i] - particle_position_vector[i]) + (c2*np.random.uniform()) * (gbest_position-particle_position_vector[i])
             # Apply velocity limits
             new_velocity=np.minimum(new_velocity, VelMax[i])
             new_velocity=np.maximum(new_velocity, VelMin[i])
@@ -321,11 +321,11 @@ def PSO_alg(wmax,wmin,c1min,c1max,c2min,c2max,initial_solution,brm_function,perc
             new_position = new_velocity + particle_position_vector[i]
             velocity_vector[i] = new_velocity
             # Velocity Mirror Effect
-            IsOutside_low=(new_position<low_bounds[i])
-            IsOutside_up=(new_position>up_bounds[i])
-            IsOutside=np.array(IsOutside_low|IsOutside_up)
-            velocity=np.array([new_velocity[j]*-1*IsOutside[j]+new_velocity[j]*(1-IsOutside[j]) for j in range(n_vars)])
-            new_velocity=velocity
+            #IsOutside_low=(new_position<low_bounds[i])
+            #IsOutside_up=(new_position>up_bounds[i])
+            #IsOutside=np.array(IsOutside_low|IsOutside_up)
+            #velocity=np.array([new_velocity[j]*-1*IsOutside[j]+new_velocity[j]*(1-IsOutside[j]) for j in range(n_vars)])
+            #new_velocity=velocity
             #Apply Position Limits Boundary Control
             position,penalty = brm_function(new_position,low_bounds[i],up_bounds[i])
             # update position
